import re
import mkdocs
from mkdocs.config import config_options


class Plugin(mkdocs.plugins.BasePlugin):
    config_scheme = (
        ("mark", config_options.Type(str, default="type:video-tag")),
        ("css_style", config_options.Type(dict, default={
            "width": "100%"
        }))
    )

    def on_page_content(self, html, page, config, files):
        # Separate tags by strings to simplify the use of regex
        content = html
        content = re.sub(r'>\s*<', '>\n<', content)

        tags = self.find_marked_tags(content)

        for tag in tags:
            src = self.get_tag_src(tag)
            if src is None:
                continue
            repl_tag = self.create_repl_tag(src)
            esc_tag = re.sub(r'\/', "\\\\/", tag)
            html = re.sub(esc_tag, repl_tag, html)

        return html


    def get_tag_src(self, tag):
        '''
        Get value of the src attribute

        return: str
        '''

        result = re.search(
            r'src=\"[^\s]*\"',
            tag
        )

        return result[0][5:-1] if result is not None else None


    def create_repl_tag(self, src):
        '''
        Сreate a replacement tag with the specified source and style.

        return: str
        '''

        style = self.config["css_style"]
        style = "; ".join(
            ["{}: {}".format(str(atr), str(style[atr])) for atr in style]
        )

        return "<video controls style=\"{}\">"\
            "<source "\
            "src=\"{}\" "\
            "type=\"video/mp4\">"\
            "</source>"\
            "</video>".format(style, src)


    def find_marked_tags(self, content):
        '''
        Find image tag with marked alternative name

        return: list
        '''

        mark = self.config["mark"]

        return re.findall(
            r'<img alt="' + mark + '" src="[^\s]*"\s*\/>',
            content
        )



from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()

setup(
    include_package_data=True,
    name='mkdocs-izsam-video',
    version='1.0.2',
    description='MkDocs plugin to insert videos in documentation.',
    long_description_content_type='text/markdown',
    long_description=README + '\n\n' + HISTORY,
    keywords=['MkDocs', 'Video', 'HTML5 video tag'],
    license='MIT',
    packages=find_packages(),
    url='',
    download_url='',
    author='Alessandro De Luca',
    author_email='al.deluca@izs.it',
    python_requires='>=3.8',    
    install_requires=[
        'mkdocs>=1.0.4'
    ],
    entry_points={
        'mkdocs.plugins': [
            'mkdocs-izsam-video = mkdocs_izsam_video.plugin:Plugin',
        ]
    }

)
